use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006001
use Test::Spelling 0.12;
use Pod::Wordlist;

add_stopwords(<DATA>);
all_pod_files_spelling_ok(qw( bin lib  ));
__DATA__
shantanu
bhadoria
CBus
CBusDevicePath
getRawReading
getReading
CDevice
CDeviceAddress
Containd
calibrate
getAccelerationVectorAngles
cartesian
gCorrectionFactor
getAccelerationVectorInG
getAccelerationVectorInMSS
getAccelerationVectorInclination
getRollYawPitch
gravitationalAcceleration
mssCorrectionFactor
Shantanu
Bhadoria
at
cpan
dott
org
lib
Device
Magnetometer
LSM303DLHC
Accelerometer
